@@ -1,4 +1,4 @@
-## $Id: AllGenerics.R 417 2010-09-18 15:49:11Z sluque $
+## $Id: AllGenerics.R 478 2011-04-03 17:10:25Z sluque $
 
 ###_ + Plotting
 if (!isGeneric("plotTDR")) {
@@ -95,7 +95,7 @@ if (!isGeneric("timeBudget")) {
                function(obj, ignoreZ) standardGeneric("timeBudget"))
 }
 
-###_ + plotBouts and bec2
+###_ + plotBouts, bec2, and bec3
 if (!isGeneric("plotBouts")) {
     setGeneric("plotBouts", function(fit, ...) standardGeneric("plotBouts"))
 }
@@ -104,6 +104,10 @@ if (!isGeneric("bec2")) {
     setGeneric("bec2", function(fit) standardGeneric("bec2"))
 }
 
+if (!isGeneric("bec3")) {
+    setGeneric("bec3", function(fit) standardGeneric("bec3"))
+}
+
 
 ###_ + Emacs local variables
 ## Local variables:
